@@ -12,7 +12,7 @@ Apache::Constants->import(':common');
 
 =head1 NAME
 
-Catalyst::Engine::Apache::MP13 - Catalyst Apache MP1.3 Engine
+Catalyst::Engine::Apache::MP13 - Catalyst Apache MP13 Engine
 
 =head1 SYNOPSIS
 
@@ -62,6 +62,15 @@ sub handler ($$) {
     shift->SUPER::handler(@_);
 }
 
+=item $c->prepare_request($r)
+
+=cut
+
+sub prepare_request {
+    my ( $c, $r ) = @_;
+    $c->apache( Apache::Request->new($r) );
+}
+
 =item $c->prepare_uploads
 
 =cut
@@ -86,15 +95,6 @@ sub prepare_uploads {
     $c->req->_assign_values( $c->req->uploads, \@uploads );
 }
 
-=item $c->prepare_request($r)
-
-=cut
-
-sub prepare_request {
-    my ( $c, $r ) = @_;
-    $c->apache( Apache::Request->new($r) );
-}
-
 =back
 
 =head1 SEE ALSO
@@ -104,6 +104,7 @@ L<Catalyst>, L<Catalyst::Engine>, L<Catalyst::Engine::Apache>.
 =head1 AUTHOR
 
 Sebastian Riedel, C<sri@cpan.org>
+Christian Hansen C<ch@ngmedia.com>
 
 =head1 COPYRIGHT
 
